from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.person_response_dto import PersonResponseDto


T = TypeVar("T", bound="PeopleResponseDto")


@_attrs_define
class PeopleResponseDto:
    """
    Attributes:
        hidden (int):
        people (list['PersonResponseDto']):
        total (int):
        has_next_page (Union[Unset, bool]): This property was added in v1.110.0
    """

    hidden: int
    people: list["PersonResponseDto"]
    total: int
    has_next_page: Union[Unset, bool] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        hidden = self.hidden

        people = []
        for people_item_data in self.people:
            people_item = people_item_data.to_dict()
            people.append(people_item)

        total = self.total

        has_next_page = self.has_next_page

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "hidden": hidden,
                "people": people,
                "total": total,
            }
        )
        if has_next_page is not UNSET:
            field_dict["hasNextPage"] = has_next_page

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.person_response_dto import PersonResponseDto

        d = dict(src_dict)
        hidden = d.pop("hidden")

        people = []
        _people = d.pop("people")
        for people_item_data in _people:
            people_item = PersonResponseDto.from_dict(people_item_data)

            people.append(people_item)

        total = d.pop("total")

        has_next_page = d.pop("hasNextPage", UNSET)

        people_response_dto = cls(
            hidden=hidden,
            people=people,
            total=total,
            has_next_page=has_next_page,
        )

        people_response_dto.additional_properties = d
        return people_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.asset_visibility import AssetVisibility
from ..types import UNSET, Unset

T = TypeVar("T", bound="TimeBucketAssetResponseDto")


@_attrs_define
class TimeBucketAssetResponseDto:
    """
    Attributes:
        city (list[Union[None, str]]): Array of city names extracted from EXIF GPS data
        country (list[Union[None, str]]): Array of country names extracted from EXIF GPS data
        duration (list[Union[None, str]]): Array of video durations in HH:MM:SS format (null for images)
        file_created_at (list[str]): Array of file creation timestamps in UTC (ISO 8601 format, without timezone)
        id (list[str]): Array of asset IDs in the time bucket
        is_favorite (list[bool]): Array indicating whether each asset is favorited
        is_image (list[bool]): Array indicating whether each asset is an image (false for videos)
        is_trashed (list[bool]): Array indicating whether each asset is in the trash
        live_photo_video_id (list[Union[None, str]]): Array of live photo video asset IDs (null for non-live photos)
        local_offset_hours (list[float]): Array of UTC offset hours at the time each photo was taken. Positive values
            are east of UTC, negative values are west of UTC. Values may be fractional (e.g., 5.5 for +05:30, -9.75 for
            -09:45). Applying this offset to 'fileCreatedAt' will give you the time the photo was taken from the
            photographer's perspective.
        owner_id (list[str]): Array of owner IDs for each asset
        projection_type (list[Union[None, str]]): Array of projection types for 360° content (e.g., "EQUIRECTANGULAR",
            "CUBEFACE", "CYLINDRICAL")
        ratio (list[float]): Array of aspect ratios (width/height) for each asset
        thumbhash (list[Union[None, str]]): Array of BlurHash strings for generating asset previews (base64 encoded)
        visibility (list[AssetVisibility]): Array of visibility statuses for each asset (e.g., ARCHIVE, TIMELINE,
            HIDDEN, LOCKED)
        latitude (Union[Unset, list[Union[None, float]]]): Array of latitude coordinates extracted from EXIF GPS data
        longitude (Union[Unset, list[Union[None, float]]]): Array of longitude coordinates extracted from EXIF GPS data
        stack (Union[Unset, list[Union[None, list[str]]]]): Array of stack information as [stackId, assetCount] tuples
            (null for non-stacked assets)
    """

    city: list[Union[None, str]]
    country: list[Union[None, str]]
    duration: list[Union[None, str]]
    file_created_at: list[str]
    id: list[str]
    is_favorite: list[bool]
    is_image: list[bool]
    is_trashed: list[bool]
    live_photo_video_id: list[Union[None, str]]
    local_offset_hours: list[float]
    owner_id: list[str]
    projection_type: list[Union[None, str]]
    ratio: list[float]
    thumbhash: list[Union[None, str]]
    visibility: list[AssetVisibility]
    latitude: Union[Unset, list[Union[None, float]]] = UNSET
    longitude: Union[Unset, list[Union[None, float]]] = UNSET
    stack: Union[Unset, list[Union[None, list[str]]]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        city = []
        for city_item_data in self.city:
            city_item: Union[None, str]
            city_item = city_item_data
            city.append(city_item)

        country = []
        for country_item_data in self.country:
            country_item: Union[None, str]
            country_item = country_item_data
            country.append(country_item)

        duration = []
        for duration_item_data in self.duration:
            duration_item: Union[None, str]
            duration_item = duration_item_data
            duration.append(duration_item)

        file_created_at = self.file_created_at

        id = self.id

        is_favorite = self.is_favorite

        is_image = self.is_image

        is_trashed = self.is_trashed

        live_photo_video_id = []
        for live_photo_video_id_item_data in self.live_photo_video_id:
            live_photo_video_id_item: Union[None, str]
            live_photo_video_id_item = live_photo_video_id_item_data
            live_photo_video_id.append(live_photo_video_id_item)

        local_offset_hours = self.local_offset_hours

        owner_id = self.owner_id

        projection_type = []
        for projection_type_item_data in self.projection_type:
            projection_type_item: Union[None, str]
            projection_type_item = projection_type_item_data
            projection_type.append(projection_type_item)

        ratio = self.ratio

        thumbhash = []
        for thumbhash_item_data in self.thumbhash:
            thumbhash_item: Union[None, str]
            thumbhash_item = thumbhash_item_data
            thumbhash.append(thumbhash_item)

        visibility = []
        for visibility_item_data in self.visibility:
            visibility_item = visibility_item_data.value
            visibility.append(visibility_item)

        latitude: Union[Unset, list[Union[None, float]]] = UNSET
        if not isinstance(self.latitude, Unset):
            latitude = []
            for latitude_item_data in self.latitude:
                latitude_item: Union[None, float]
                latitude_item = latitude_item_data
                latitude.append(latitude_item)

        longitude: Union[Unset, list[Union[None, float]]] = UNSET
        if not isinstance(self.longitude, Unset):
            longitude = []
            for longitude_item_data in self.longitude:
                longitude_item: Union[None, float]
                longitude_item = longitude_item_data
                longitude.append(longitude_item)

        stack: Union[Unset, list[Union[None, list[str]]]] = UNSET
        if not isinstance(self.stack, Unset):
            stack = []
            for stack_item_data in self.stack:
                stack_item: Union[None, list[str]]
                if isinstance(stack_item_data, list):
                    stack_item = stack_item_data

                else:
                    stack_item = stack_item_data
                stack.append(stack_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "city": city,
                "country": country,
                "duration": duration,
                "fileCreatedAt": file_created_at,
                "id": id,
                "isFavorite": is_favorite,
                "isImage": is_image,
                "isTrashed": is_trashed,
                "livePhotoVideoId": live_photo_video_id,
                "localOffsetHours": local_offset_hours,
                "ownerId": owner_id,
                "projectionType": projection_type,
                "ratio": ratio,
                "thumbhash": thumbhash,
                "visibility": visibility,
            }
        )
        if latitude is not UNSET:
            field_dict["latitude"] = latitude
        if longitude is not UNSET:
            field_dict["longitude"] = longitude
        if stack is not UNSET:
            field_dict["stack"] = stack

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        city = []
        _city = d.pop("city")
        for city_item_data in _city:

            def _parse_city_item(data: object) -> Union[None, str]:
                if data is None:
                    return data
                return cast(Union[None, str], data)

            city_item = _parse_city_item(city_item_data)

            city.append(city_item)

        country = []
        _country = d.pop("country")
        for country_item_data in _country:

            def _parse_country_item(data: object) -> Union[None, str]:
                if data is None:
                    return data
                return cast(Union[None, str], data)

            country_item = _parse_country_item(country_item_data)

            country.append(country_item)

        duration = []
        _duration = d.pop("duration")
        for duration_item_data in _duration:

            def _parse_duration_item(data: object) -> Union[None, str]:
                if data is None:
                    return data
                return cast(Union[None, str], data)

            duration_item = _parse_duration_item(duration_item_data)

            duration.append(duration_item)

        file_created_at = cast(list[str], d.pop("fileCreatedAt"))

        id = cast(list[str], d.pop("id"))

        is_favorite = cast(list[bool], d.pop("isFavorite"))

        is_image = cast(list[bool], d.pop("isImage"))

        is_trashed = cast(list[bool], d.pop("isTrashed"))

        live_photo_video_id = []
        _live_photo_video_id = d.pop("livePhotoVideoId")
        for live_photo_video_id_item_data in _live_photo_video_id:

            def _parse_live_photo_video_id_item(data: object) -> Union[None, str]:
                if data is None:
                    return data
                return cast(Union[None, str], data)

            live_photo_video_id_item = _parse_live_photo_video_id_item(
                live_photo_video_id_item_data
            )

            live_photo_video_id.append(live_photo_video_id_item)

        local_offset_hours = cast(list[float], d.pop("localOffsetHours"))

        owner_id = cast(list[str], d.pop("ownerId"))

        projection_type = []
        _projection_type = d.pop("projectionType")
        for projection_type_item_data in _projection_type:

            def _parse_projection_type_item(data: object) -> Union[None, str]:
                if data is None:
                    return data
                return cast(Union[None, str], data)

            projection_type_item = _parse_projection_type_item(
                projection_type_item_data
            )

            projection_type.append(projection_type_item)

        ratio = cast(list[float], d.pop("ratio"))

        thumbhash = []
        _thumbhash = d.pop("thumbhash")
        for thumbhash_item_data in _thumbhash:

            def _parse_thumbhash_item(data: object) -> Union[None, str]:
                if data is None:
                    return data
                return cast(Union[None, str], data)

            thumbhash_item = _parse_thumbhash_item(thumbhash_item_data)

            thumbhash.append(thumbhash_item)

        visibility = []
        _visibility = d.pop("visibility")
        for visibility_item_data in _visibility:
            visibility_item = AssetVisibility(visibility_item_data)

            visibility.append(visibility_item)

        latitude = []
        _latitude = d.pop("latitude", UNSET)
        for latitude_item_data in _latitude or []:

            def _parse_latitude_item(data: object) -> Union[None, float]:
                if data is None:
                    return data
                return cast(Union[None, float], data)

            latitude_item = _parse_latitude_item(latitude_item_data)

            latitude.append(latitude_item)

        longitude = []
        _longitude = d.pop("longitude", UNSET)
        for longitude_item_data in _longitude or []:

            def _parse_longitude_item(data: object) -> Union[None, float]:
                if data is None:
                    return data
                return cast(Union[None, float], data)

            longitude_item = _parse_longitude_item(longitude_item_data)

            longitude.append(longitude_item)

        stack = []
        _stack = d.pop("stack", UNSET)
        for stack_item_data in _stack or []:

            def _parse_stack_item(data: object) -> Union[None, list[str]]:
                if data is None:
                    return data
                try:
                    if not isinstance(data, list):
                        raise TypeError()
                    stack_item_type_0 = cast(list[str], data)

                    return stack_item_type_0
                except:  # noqa: E722
                    pass
                return cast(Union[None, list[str]], data)

            stack_item = _parse_stack_item(stack_item_data)

            stack.append(stack_item)

        time_bucket_asset_response_dto = cls(
            city=city,
            country=country,
            duration=duration,
            file_created_at=file_created_at,
            id=id,
            is_favorite=is_favorite,
            is_image=is_image,
            is_trashed=is_trashed,
            live_photo_video_id=live_photo_video_id,
            local_offset_hours=local_offset_hours,
            owner_id=owner_id,
            projection_type=projection_type,
            ratio=ratio,
            thumbhash=thumbhash,
            visibility=visibility,
            latitude=latitude,
            longitude=longitude,
            stack=stack,
        )

        time_bucket_asset_response_dto.additional_properties = d
        return time_bucket_asset_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.memory_type import MemoryType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.asset_response_dto import AssetResponseDto
    from ..models.on_this_day_dto import OnThisDayDto


T = TypeVar("T", bound="MemoryResponseDto")


@_attrs_define
class MemoryResponseDto:
    """
    Attributes:
        assets (list['AssetResponseDto']):
        created_at (datetime.datetime):
        data (OnThisDayDto):
        id (str):
        is_saved (bool):
        memory_at (datetime.datetime):
        owner_id (str):
        type_ (MemoryType):
        updated_at (datetime.datetime):
        deleted_at (Union[Unset, datetime.datetime]):
        hide_at (Union[Unset, datetime.datetime]):
        seen_at (Union[Unset, datetime.datetime]):
        show_at (Union[Unset, datetime.datetime]):
    """

    assets: list["AssetResponseDto"]
    created_at: datetime.datetime
    data: "OnThisDayDto"
    id: str
    is_saved: bool
    memory_at: datetime.datetime
    owner_id: str
    type_: MemoryType
    updated_at: datetime.datetime
    deleted_at: Union[Unset, datetime.datetime] = UNSET
    hide_at: Union[Unset, datetime.datetime] = UNSET
    seen_at: Union[Unset, datetime.datetime] = UNSET
    show_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        assets = []
        for assets_item_data in self.assets:
            assets_item = assets_item_data.to_dict()
            assets.append(assets_item)

        created_at = self.created_at.isoformat()

        data = self.data.to_dict()

        id = self.id

        is_saved = self.is_saved

        memory_at = self.memory_at.isoformat()

        owner_id = self.owner_id

        type_ = self.type_.value

        updated_at = self.updated_at.isoformat()

        deleted_at: Union[Unset, str] = UNSET
        if not isinstance(self.deleted_at, Unset):
            deleted_at = self.deleted_at.isoformat()

        hide_at: Union[Unset, str] = UNSET
        if not isinstance(self.hide_at, Unset):
            hide_at = self.hide_at.isoformat()

        seen_at: Union[Unset, str] = UNSET
        if not isinstance(self.seen_at, Unset):
            seen_at = self.seen_at.isoformat()

        show_at: Union[Unset, str] = UNSET
        if not isinstance(self.show_at, Unset):
            show_at = self.show_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "assets": assets,
                "createdAt": created_at,
                "data": data,
                "id": id,
                "isSaved": is_saved,
                "memoryAt": memory_at,
                "ownerId": owner_id,
                "type": type_,
                "updatedAt": updated_at,
            }
        )
        if deleted_at is not UNSET:
            field_dict["deletedAt"] = deleted_at
        if hide_at is not UNSET:
            field_dict["hideAt"] = hide_at
        if seen_at is not UNSET:
            field_dict["seenAt"] = seen_at
        if show_at is not UNSET:
            field_dict["showAt"] = show_at

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.asset_response_dto import AssetResponseDto
        from ..models.on_this_day_dto import OnThisDayDto

        d = dict(src_dict)
        assets = []
        _assets = d.pop("assets")
        for assets_item_data in _assets:
            assets_item = AssetResponseDto.from_dict(assets_item_data)

            assets.append(assets_item)

        created_at = isoparse(d.pop("createdAt"))

        data = OnThisDayDto.from_dict(d.pop("data"))

        id = d.pop("id")

        is_saved = d.pop("isSaved")

        memory_at = isoparse(d.pop("memoryAt"))

        owner_id = d.pop("ownerId")

        type_ = MemoryType(d.pop("type"))

        updated_at = isoparse(d.pop("updatedAt"))

        _deleted_at = d.pop("deletedAt", UNSET)
        deleted_at: Union[Unset, datetime.datetime]
        if isinstance(_deleted_at, Unset):
            deleted_at = UNSET
        else:
            deleted_at = isoparse(_deleted_at)

        _hide_at = d.pop("hideAt", UNSET)
        hide_at: Union[Unset, datetime.datetime]
        if isinstance(_hide_at, Unset):
            hide_at = UNSET
        else:
            hide_at = isoparse(_hide_at)

        _seen_at = d.pop("seenAt", UNSET)
        seen_at: Union[Unset, datetime.datetime]
        if isinstance(_seen_at, Unset):
            seen_at = UNSET
        else:
            seen_at = isoparse(_seen_at)

        _show_at = d.pop("showAt", UNSET)
        show_at: Union[Unset, datetime.datetime]
        if isinstance(_show_at, Unset):
            show_at = UNSET
        else:
            show_at = isoparse(_show_at)

        memory_response_dto = cls(
            assets=assets,
            created_at=created_at,
            data=data,
            id=id,
            is_saved=is_saved,
            memory_at=memory_at,
            owner_id=owner_id,
            type_=type_,
            updated_at=updated_at,
            deleted_at=deleted_at,
            hide_at=hide_at,
            seen_at=seen_at,
            show_at=show_at,
        )

        memory_response_dto.additional_properties = d
        return memory_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="JobCountsDto")


@_attrs_define
class JobCountsDto:
    """
    Attributes:
        active (int):
        completed (int):
        delayed (int):
        failed (int):
        paused (int):
        waiting (int):
    """

    active: int
    completed: int
    delayed: int
    failed: int
    paused: int
    waiting: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        active = self.active

        completed = self.completed

        delayed = self.delayed

        failed = self.failed

        paused = self.paused

        waiting = self.waiting

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "active": active,
                "completed": completed,
                "delayed": delayed,
                "failed": failed,
                "paused": paused,
                "waiting": waiting,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        active = d.pop("active")

        completed = d.pop("completed")

        delayed = d.pop("delayed")

        failed = d.pop("failed")

        paused = d.pop("paused")

        waiting = d.pop("waiting")

        job_counts_dto = cls(
            active=active,
            completed=completed,
            delayed=delayed,
            failed=failed,
            paused=paused,
            waiting=waiting,
        )

        job_counts_dto.additional_properties = d
        return job_counts_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="ServerFeaturesDto")


@_attrs_define
class ServerFeaturesDto:
    """
    Attributes:
        config_file (bool):
        duplicate_detection (bool):
        email (bool):
        facial_recognition (bool):
        import_faces (bool):
        map_ (bool):
        oauth (bool):
        oauth_auto_launch (bool):
        password_login (bool):
        reverse_geocoding (bool):
        search (bool):
        sidecar (bool):
        smart_search (bool):
        trash (bool):
    """

    config_file: bool
    duplicate_detection: bool
    email: bool
    facial_recognition: bool
    import_faces: bool
    map_: bool
    oauth: bool
    oauth_auto_launch: bool
    password_login: bool
    reverse_geocoding: bool
    search: bool
    sidecar: bool
    smart_search: bool
    trash: bool
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        config_file = self.config_file

        duplicate_detection = self.duplicate_detection

        email = self.email

        facial_recognition = self.facial_recognition

        import_faces = self.import_faces

        map_ = self.map_

        oauth = self.oauth

        oauth_auto_launch = self.oauth_auto_launch

        password_login = self.password_login

        reverse_geocoding = self.reverse_geocoding

        search = self.search

        sidecar = self.sidecar

        smart_search = self.smart_search

        trash = self.trash

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "configFile": config_file,
                "duplicateDetection": duplicate_detection,
                "email": email,
                "facialRecognition": facial_recognition,
                "importFaces": import_faces,
                "map": map_,
                "oauth": oauth,
                "oauthAutoLaunch": oauth_auto_launch,
                "passwordLogin": password_login,
                "reverseGeocoding": reverse_geocoding,
                "search": search,
                "sidecar": sidecar,
                "smartSearch": smart_search,
                "trash": trash,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        config_file = d.pop("configFile")

        duplicate_detection = d.pop("duplicateDetection")

        email = d.pop("email")

        facial_recognition = d.pop("facialRecognition")

        import_faces = d.pop("importFaces")

        map_ = d.pop("map")

        oauth = d.pop("oauth")

        oauth_auto_launch = d.pop("oauthAutoLaunch")

        password_login = d.pop("passwordLogin")

        reverse_geocoding = d.pop("reverseGeocoding")

        search = d.pop("search")

        sidecar = d.pop("sidecar")

        smart_search = d.pop("smartSearch")

        trash = d.pop("trash")

        server_features_dto = cls(
            config_file=config_file,
            duplicate_detection=duplicate_detection,
            email=email,
            facial_recognition=facial_recognition,
            import_faces=import_faces,
            map_=map_,
            oauth=oauth,
            oauth_auto_launch=oauth_auto_launch,
            password_login=password_login,
            reverse_geocoding=reverse_geocoding,
            search=search,
            sidecar=sidecar,
            smart_search=smart_search,
            trash=trash,
        )

        server_features_dto.additional_properties = d
        return server_features_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.asset_type_enum import AssetTypeEnum
from ..models.asset_visibility import AssetVisibility
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.asset_face_without_person_response_dto import (
        AssetFaceWithoutPersonResponseDto,
    )
    from ..models.asset_stack_response_dto import AssetStackResponseDto
    from ..models.exif_response_dto import ExifResponseDto
    from ..models.person_with_faces_response_dto import PersonWithFacesResponseDto
    from ..models.tag_response_dto import TagResponseDto
    from ..models.user_response_dto import UserResponseDto


T = TypeVar("T", bound="AssetResponseDto")


@_attrs_define
class AssetResponseDto:
    """
    Attributes:
        checksum (str): base64 encoded sha1 hash
        created_at (datetime.datetime): The UTC timestamp when the asset was originally uploaded to Immich. Example:
            2024-01-15T20:30:00.000Z.
        device_asset_id (str):
        device_id (str):
        duration (str):
        file_created_at (datetime.datetime): The actual UTC timestamp when the file was created/captured, preserving
            timezone information. This is the authoritative timestamp for chronological sorting within timeline groups.
            Combined with timezone data, this can be used to determine the exact moment the photo was taken. Example:
            2024-01-15T19:30:00.000Z.
        file_modified_at (datetime.datetime): The UTC timestamp when the file was last modified on the filesystem. This
            reflects the last time the physical file was changed, which may be different from when the photo was originally
            taken. Example: 2024-01-16T10:15:00.000Z.
        has_metadata (bool):
        id (str):
        is_archived (bool):
        is_favorite (bool):
        is_offline (bool):
        is_trashed (bool):
        local_date_time (datetime.datetime): The local date and time when the photo/video was taken, derived from EXIF
            metadata. This represents the photographer's local time regardless of timezone, stored as a timezone-agnostic
            timestamp. Used for timeline grouping by "local" days and months. Example: 2024-01-15T14:30:00.000Z.
        original_file_name (str):
        original_path (str):
        owner_id (str):
        thumbhash (Union[None, str]):
        type_ (AssetTypeEnum):
        updated_at (datetime.datetime): The UTC timestamp when the asset record was last updated in the database. This
            is automatically maintained by the database and reflects when any field in the asset was last modified. Example:
            2024-01-16T12:45:30.000Z.
        visibility (AssetVisibility):
        duplicate_id (Union[None, Unset, str]):
        exif_info (Union[Unset, ExifResponseDto]):
        library_id (Union[None, Unset, str]): This property was deprecated in v1.106.0
        live_photo_video_id (Union[None, Unset, str]):
        original_mime_type (Union[Unset, str]):
        owner (Union[Unset, UserResponseDto]):
        people (Union[Unset, list['PersonWithFacesResponseDto']]):
        resized (Union[Unset, bool]): This property was deprecated in v1.113.0
        stack (Union['AssetStackResponseDto', None, Unset]):
        tags (Union[Unset, list['TagResponseDto']]):
        unassigned_faces (Union[Unset, list['AssetFaceWithoutPersonResponseDto']]):
    """

    checksum: str
    created_at: datetime.datetime
    device_asset_id: str
    device_id: str
    duration: str
    file_created_at: datetime.datetime
    file_modified_at: datetime.datetime
    has_metadata: bool
    id: str
    is_archived: bool
    is_favorite: bool
    is_offline: bool
    is_trashed: bool
    local_date_time: datetime.datetime
    original_file_name: str
    original_path: str
    owner_id: str
    thumbhash: Union[None, str]
    type_: AssetTypeEnum
    updated_at: datetime.datetime
    visibility: AssetVisibility
    duplicate_id: Union[None, Unset, str] = UNSET
    exif_info: Union[Unset, "ExifResponseDto"] = UNSET
    library_id: Union[None, Unset, str] = UNSET
    live_photo_video_id: Union[None, Unset, str] = UNSET
    original_mime_type: Union[Unset, str] = UNSET
    owner: Union[Unset, "UserResponseDto"] = UNSET
    people: Union[Unset, list["PersonWithFacesResponseDto"]] = UNSET
    resized: Union[Unset, bool] = UNSET
    stack: Union["AssetStackResponseDto", None, Unset] = UNSET
    tags: Union[Unset, list["TagResponseDto"]] = UNSET
    unassigned_faces: Union[Unset, list["AssetFaceWithoutPersonResponseDto"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.asset_stack_response_dto import AssetStackResponseDto

        checksum = self.checksum

        created_at = self.created_at.isoformat()

        device_asset_id = self.device_asset_id

        device_id = self.device_id

        duration = self.duration

        file_created_at = self.file_created_at.isoformat()

        file_modified_at = self.file_modified_at.isoformat()

        has_metadata = self.has_metadata

        id = self.id

        is_archived = self.is_archived

        is_favorite = self.is_favorite

        is_offline = self.is_offline

        is_trashed = self.is_trashed

        local_date_time = self.local_date_time.isoformat()

        original_file_name = self.original_file_name

        original_path = self.original_path

        owner_id = self.owner_id

        thumbhash: Union[None, str]
        thumbhash = self.thumbhash

        type_ = self.type_.value

        updated_at = self.updated_at.isoformat()

        visibility = self.visibility.value

        duplicate_id: Union[None, Unset, str]
        if isinstance(self.duplicate_id, Unset):
            duplicate_id = UNSET
        else:
            duplicate_id = self.duplicate_id

        exif_info: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.exif_info, Unset):
            exif_info = self.exif_info.to_dict()

        library_id: Union[None, Unset, str]
        if isinstance(self.library_id, Unset):
            library_id = UNSET
        else:
            library_id = self.library_id

        live_photo_video_id: Union[None, Unset, str]
        if isinstance(self.live_photo_video_id, Unset):
            live_photo_video_id = UNSET
        else:
            live_photo_video_id = self.live_photo_video_id

        original_mime_type = self.original_mime_type

        owner: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.owner, Unset):
            owner = self.owner.to_dict()

        people: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.people, Unset):
            people = []
            for people_item_data in self.people:
                people_item = people_item_data.to_dict()
                people.append(people_item)

        resized = self.resized

        stack: Union[None, Unset, dict[str, Any]]
        if isinstance(self.stack, Unset):
            stack = UNSET
        elif isinstance(self.stack, AssetStackResponseDto):
            stack = self.stack.to_dict()
        else:
            stack = self.stack

        tags: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = []
            for tags_item_data in self.tags:
                tags_item = tags_item_data.to_dict()
                tags.append(tags_item)

        unassigned_faces: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.unassigned_faces, Unset):
            unassigned_faces = []
            for unassigned_faces_item_data in self.unassigned_faces:
                unassigned_faces_item = unassigned_faces_item_data.to_dict()
                unassigned_faces.append(unassigned_faces_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "checksum": checksum,
                "createdAt": created_at,
                "deviceAssetId": device_asset_id,
                "deviceId": device_id,
                "duration": duration,
                "fileCreatedAt": file_created_at,
                "fileModifiedAt": file_modified_at,
                "hasMetadata": has_metadata,
                "id": id,
                "isArchived": is_archived,
                "isFavorite": is_favorite,
                "isOffline": is_offline,
                "isTrashed": is_trashed,
                "localDateTime": local_date_time,
                "originalFileName": original_file_name,
                "originalPath": original_path,
                "ownerId": owner_id,
                "thumbhash": thumbhash,
                "type": type_,
                "updatedAt": updated_at,
                "visibility": visibility,
            }
        )
        if duplicate_id is not UNSET:
            field_dict["duplicateId"] = duplicate_id
        if exif_info is not UNSET:
            field_dict["exifInfo"] = exif_info
        if library_id is not UNSET:
            field_dict["libraryId"] = library_id
        if live_photo_video_id is not UNSET:
            field_dict["livePhotoVideoId"] = live_photo_video_id
        if original_mime_type is not UNSET:
            field_dict["originalMimeType"] = original_mime_type
        if owner is not UNSET:
            field_dict["owner"] = owner
        if people is not UNSET:
            field_dict["people"] = people
        if resized is not UNSET:
            field_dict["resized"] = resized
        if stack is not UNSET:
            field_dict["stack"] = stack
        if tags is not UNSET:
            field_dict["tags"] = tags
        if unassigned_faces is not UNSET:
            field_dict["unassignedFaces"] = unassigned_faces

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.asset_face_without_person_response_dto import (
            AssetFaceWithoutPersonResponseDto,
        )
        from ..models.asset_stack_response_dto import AssetStackResponseDto
        from ..models.exif_response_dto import ExifResponseDto
        from ..models.person_with_faces_response_dto import PersonWithFacesResponseDto
        from ..models.tag_response_dto import TagResponseDto
        from ..models.user_response_dto import UserResponseDto

        d = dict(src_dict)
        checksum = d.pop("checksum")

        created_at = isoparse(d.pop("createdAt"))

        device_asset_id = d.pop("deviceAssetId")

        device_id = d.pop("deviceId")

        duration = d.pop("duration")

        file_created_at = isoparse(d.pop("fileCreatedAt"))

        file_modified_at = isoparse(d.pop("fileModifiedAt"))

        has_metadata = d.pop("hasMetadata")

        id = d.pop("id")

        is_archived = d.pop("isArchived")

        is_favorite = d.pop("isFavorite")

        is_offline = d.pop("isOffline")

        is_trashed = d.pop("isTrashed")

        local_date_time = isoparse(d.pop("localDateTime"))

        original_file_name = d.pop("originalFileName")

        original_path = d.pop("originalPath")

        owner_id = d.pop("ownerId")

        def _parse_thumbhash(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        thumbhash = _parse_thumbhash(d.pop("thumbhash"))

        type_ = AssetTypeEnum(d.pop("type"))

        updated_at = isoparse(d.pop("updatedAt"))

        visibility = AssetVisibility(d.pop("visibility"))

        def _parse_duplicate_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        duplicate_id = _parse_duplicate_id(d.pop("duplicateId", UNSET))

        _exif_info = d.pop("exifInfo", UNSET)
        exif_info: Union[Unset, ExifResponseDto]
        if isinstance(_exif_info, Unset):
            exif_info = UNSET
        else:
            exif_info = ExifResponseDto.from_dict(_exif_info)

        def _parse_library_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        library_id = _parse_library_id(d.pop("libraryId", UNSET))

        def _parse_live_photo_video_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        live_photo_video_id = _parse_live_photo_video_id(
            d.pop("livePhotoVideoId", UNSET)
        )

        original_mime_type = d.pop("originalMimeType", UNSET)

        _owner = d.pop("owner", UNSET)
        owner: Union[Unset, UserResponseDto]
        if isinstance(_owner, Unset):
            owner = UNSET
        else:
            owner = UserResponseDto.from_dict(_owner)

        people = []
        _people = d.pop("people", UNSET)
        for people_item_data in _people or []:
            people_item = PersonWithFacesResponseDto.from_dict(people_item_data)

            people.append(people_item)

        resized = d.pop("resized", UNSET)

        def _parse_stack(data: object) -> Union["AssetStackResponseDto", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                stack_type_1 = AssetStackResponseDto.from_dict(data)

                return stack_type_1
            except:  # noqa: E722
                pass
            return cast(Union["AssetStackResponseDto", None, Unset], data)

        stack = _parse_stack(d.pop("stack", UNSET))

        tags = []
        _tags = d.pop("tags", UNSET)
        for tags_item_data in _tags or []:
            tags_item = TagResponseDto.from_dict(tags_item_data)

            tags.append(tags_item)

        unassigned_faces = []
        _unassigned_faces = d.pop("unassignedFaces", UNSET)
        for unassigned_faces_item_data in _unassigned_faces or []:
            unassigned_faces_item = AssetFaceWithoutPersonResponseDto.from_dict(
                unassigned_faces_item_data
            )

            unassigned_faces.append(unassigned_faces_item)

        asset_response_dto = cls(
            checksum=checksum,
            created_at=created_at,
            device_asset_id=device_asset_id,
            device_id=device_id,
            duration=duration,
            file_created_at=file_created_at,
            file_modified_at=file_modified_at,
            has_metadata=has_metadata,
            id=id,
            is_archived=is_archived,
            is_favorite=is_favorite,
            is_offline=is_offline,
            is_trashed=is_trashed,
            local_date_time=local_date_time,
            original_file_name=original_file_name,
            original_path=original_path,
            owner_id=owner_id,
            thumbhash=thumbhash,
            type_=type_,
            updated_at=updated_at,
            visibility=visibility,
            duplicate_id=duplicate_id,
            exif_info=exif_info,
            library_id=library_id,
            live_photo_video_id=live_photo_video_id,
            original_mime_type=original_mime_type,
            owner=owner,
            people=people,
            resized=resized,
            stack=stack,
            tags=tags,
            unassigned_faces=unassigned_faces,
        )

        asset_response_dto.additional_properties = d
        return asset_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class AssetIdsResponseDtoError(str, Enum):
    DUPLICATE = "duplicate"
    NOT_FOUND = "not_found"
    NO_PERMISSION = "no_permission"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="SessionCreateDto")


@_attrs_define
class SessionCreateDto:
    """
    Attributes:
        device_os (Union[Unset, str]):
        device_type (Union[Unset, str]):
        duration (Union[Unset, float]): session duration, in seconds
    """

    device_os: Union[Unset, str] = UNSET
    device_type: Union[Unset, str] = UNSET
    duration: Union[Unset, float] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        device_os = self.device_os

        device_type = self.device_type

        duration = self.duration

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if device_os is not UNSET:
            field_dict["deviceOS"] = device_os
        if device_type is not UNSET:
            field_dict["deviceType"] = device_type
        if duration is not UNSET:
            field_dict["duration"] = duration

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        device_os = d.pop("deviceOS", UNSET)

        device_type = d.pop("deviceType", UNSET)

        duration = d.pop("duration", UNSET)

        session_create_dto = cls(
            device_os=device_os,
            device_type=device_type,
            duration=duration,
        )

        session_create_dto.additional_properties = d
        return session_create_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.validate_library_import_path_response_dto import (
        ValidateLibraryImportPathResponseDto,
    )


T = TypeVar("T", bound="ValidateLibraryResponseDto")


@_attrs_define
class ValidateLibraryResponseDto:
    """
    Attributes:
        import_paths (Union[Unset, list['ValidateLibraryImportPathResponseDto']]):
    """

    import_paths: Union[Unset, list["ValidateLibraryImportPathResponseDto"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        import_paths: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.import_paths, Unset):
            import_paths = []
            for import_paths_item_data in self.import_paths:
                import_paths_item = import_paths_item_data.to_dict()
                import_paths.append(import_paths_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if import_paths is not UNSET:
            field_dict["importPaths"] = import_paths

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.validate_library_import_path_response_dto import (
            ValidateLibraryImportPathResponseDto,
        )

        d = dict(src_dict)
        import_paths = []
        _import_paths = d.pop("importPaths", UNSET)
        for import_paths_item_data in _import_paths or []:
            import_paths_item = ValidateLibraryImportPathResponseDto.from_dict(
                import_paths_item_data
            )

            import_paths.append(import_paths_item)

        validate_library_response_dto = cls(
            import_paths=import_paths,
        )

        validate_library_response_dto.additional_properties = d
        return validate_library_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

T = TypeVar("T", bound="SyncAssetExifV1")


@_attrs_define
class SyncAssetExifV1:
    """
    Attributes:
        asset_id (str):
        city (Union[None, str]):
        country (Union[None, str]):
        date_time_original (Union[None, datetime.datetime]):
        description (Union[None, str]):
        exif_image_height (Union[None, int]):
        exif_image_width (Union[None, int]):
        exposure_time (Union[None, str]):
        f_number (Union[None, float]):
        file_size_in_byte (Union[None, int]):
        focal_length (Union[None, float]):
        fps (Union[None, float]):
        iso (Union[None, int]):
        latitude (Union[None, float]):
        lens_model (Union[None, str]):
        longitude (Union[None, float]):
        make (Union[None, str]):
        model (Union[None, str]):
        modify_date (Union[None, datetime.datetime]):
        orientation (Union[None, str]):
        profile_description (Union[None, str]):
        projection_type (Union[None, str]):
        rating (Union[None, int]):
        state (Union[None, str]):
        time_zone (Union[None, str]):
    """

    asset_id: str
    city: Union[None, str]
    country: Union[None, str]
    date_time_original: Union[None, datetime.datetime]
    description: Union[None, str]
    exif_image_height: Union[None, int]
    exif_image_width: Union[None, int]
    exposure_time: Union[None, str]
    f_number: Union[None, float]
    file_size_in_byte: Union[None, int]
    focal_length: Union[None, float]
    fps: Union[None, float]
    iso: Union[None, int]
    latitude: Union[None, float]
    lens_model: Union[None, str]
    longitude: Union[None, float]
    make: Union[None, str]
    model: Union[None, str]
    modify_date: Union[None, datetime.datetime]
    orientation: Union[None, str]
    profile_description: Union[None, str]
    projection_type: Union[None, str]
    rating: Union[None, int]
    state: Union[None, str]
    time_zone: Union[None, str]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        asset_id = self.asset_id

        city: Union[None, str]
        city = self.city

        country: Union[None, str]
        country = self.country

        date_time_original: Union[None, str]
        if isinstance(self.date_time_original, datetime.datetime):
            date_time_original = self.date_time_original.isoformat()
        else:
            date_time_original = self.date_time_original

        description: Union[None, str]
        description = self.description

        exif_image_height: Union[None, int]
        exif_image_height = self.exif_image_height

        exif_image_width: Union[None, int]
        exif_image_width = self.exif_image_width

        exposure_time: Union[None, str]
        exposure_time = self.exposure_time

        f_number: Union[None, float]
        f_number = self.f_number

        file_size_in_byte: Union[None, int]
        file_size_in_byte = self.file_size_in_byte

        focal_length: Union[None, float]
        focal_length = self.focal_length

        fps: Union[None, float]
        fps = self.fps

        iso: Union[None, int]
        iso = self.iso

        latitude: Union[None, float]
        latitude = self.latitude

        lens_model: Union[None, str]
        lens_model = self.lens_model

        longitude: Union[None, float]
        longitude = self.longitude

        make: Union[None, str]
        make = self.make

        model: Union[None, str]
        model = self.model

        modify_date: Union[None, str]
        if isinstance(self.modify_date, datetime.datetime):
            modify_date = self.modify_date.isoformat()
        else:
            modify_date = self.modify_date

        orientation: Union[None, str]
        orientation = self.orientation

        profile_description: Union[None, str]
        profile_description = self.profile_description

        projection_type: Union[None, str]
        projection_type = self.projection_type

        rating: Union[None, int]
        rating = self.rating

        state: Union[None, str]
        state = self.state

        time_zone: Union[None, str]
        time_zone = self.time_zone

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "assetId": asset_id,
                "city": city,
                "country": country,
                "dateTimeOriginal": date_time_original,
                "description": description,
                "exifImageHeight": exif_image_height,
                "exifImageWidth": exif_image_width,
                "exposureTime": exposure_time,
                "fNumber": f_number,
                "fileSizeInByte": file_size_in_byte,
                "focalLength": focal_length,
                "fps": fps,
                "iso": iso,
                "latitude": latitude,
                "lensModel": lens_model,
                "longitude": longitude,
                "make": make,
                "model": model,
                "modifyDate": modify_date,
                "orientation": orientation,
                "profileDescription": profile_description,
                "projectionType": projection_type,
                "rating": rating,
                "state": state,
                "timeZone": time_zone,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        asset_id = d.pop("assetId")

        def _parse_city(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        city = _parse_city(d.pop("city"))

        def _parse_country(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        country = _parse_country(d.pop("country"))

        def _parse_date_time_original(data: object) -> Union[None, datetime.datetime]:
            if data is None:
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_time_original_type_0 = isoparse(data)

                return date_time_original_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, datetime.datetime], data)

        date_time_original = _parse_date_time_original(d.pop("dateTimeOriginal"))

        def _parse_description(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        description = _parse_description(d.pop("description"))

        def _parse_exif_image_height(data: object) -> Union[None, int]:
            if data is None:
                return data
            return cast(Union[None, int], data)

        exif_image_height = _parse_exif_image_height(d.pop("exifImageHeight"))

        def _parse_exif_image_width(data: object) -> Union[None, int]:
            if data is None:
                return data
            return cast(Union[None, int], data)

        exif_image_width = _parse_exif_image_width(d.pop("exifImageWidth"))

        def _parse_exposure_time(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        exposure_time = _parse_exposure_time(d.pop("exposureTime"))

        def _parse_f_number(data: object) -> Union[None, float]:
            if data is None:
                return data
            return cast(Union[None, float], data)

        f_number = _parse_f_number(d.pop("fNumber"))

        def _parse_file_size_in_byte(data: object) -> Union[None, int]:
            if data is None:
                return data
            return cast(Union[None, int], data)

        file_size_in_byte = _parse_file_size_in_byte(d.pop("fileSizeInByte"))

        def _parse_focal_length(data: object) -> Union[None, float]:
            if data is None:
                return data
            return cast(Union[None, float], data)

        focal_length = _parse_focal_length(d.pop("focalLength"))

        def _parse_fps(data: object) -> Union[None, float]:
            if data is None:
                return data
            return cast(Union[None, float], data)

        fps = _parse_fps(d.pop("fps"))

        def _parse_iso(data: object) -> Union[None, int]:
            if data is None:
                return data
            return cast(Union[None, int], data)

        iso = _parse_iso(d.pop("iso"))

        def _parse_latitude(data: object) -> Union[None, float]:
            if data is None:
                return data
            return cast(Union[None, float], data)

        latitude = _parse_latitude(d.pop("latitude"))

        def _parse_lens_model(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        lens_model = _parse_lens_model(d.pop("lensModel"))

        def _parse_longitude(data: object) -> Union[None, float]:
            if data is None:
                return data
            return cast(Union[None, float], data)

        longitude = _parse_longitude(d.pop("longitude"))

        def _parse_make(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        make = _parse_make(d.pop("make"))

        def _parse_model(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        model = _parse_model(d.pop("model"))

        def _parse_modify_date(data: object) -> Union[None, datetime.datetime]:
            if data is None:
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                modify_date_type_0 = isoparse(data)

                return modify_date_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, datetime.datetime], data)

        modify_date = _parse_modify_date(d.pop("modifyDate"))

        def _parse_orientation(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        orientation = _parse_orientation(d.pop("orientation"))

        def _parse_profile_description(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        profile_description = _parse_profile_description(d.pop("profileDescription"))

        def _parse_projection_type(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        projection_type = _parse_projection_type(d.pop("projectionType"))

        def _parse_rating(data: object) -> Union[None, int]:
            if data is None:
                return data
            return cast(Union[None, int], data)

        rating = _parse_rating(d.pop("rating"))

        def _parse_state(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        state = _parse_state(d.pop("state"))

        def _parse_time_zone(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        time_zone = _parse_time_zone(d.pop("timeZone"))

        sync_asset_exif_v1 = cls(
            asset_id=asset_id,
            city=city,
            country=country,
            date_time_original=date_time_original,
            description=description,
            exif_image_height=exif_image_height,
            exif_image_width=exif_image_width,
            exposure_time=exposure_time,
            f_number=f_number,
            file_size_in_byte=file_size_in_byte,
            focal_length=focal_length,
            fps=fps,
            iso=iso,
            latitude=latitude,
            lens_model=lens_model,
            longitude=longitude,
            make=make,
            model=model,
            modify_date=modify_date,
            orientation=orientation,
            profile_description=profile_description,
            projection_type=projection_type,
            rating=rating,
            state=state,
            time_zone=time_zone,
        )

        sync_asset_exif_v1.additional_properties = d
        return sync_asset_exif_v1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ServerAboutResponseDto")


@_attrs_define
class ServerAboutResponseDto:
    """
    Attributes:
        licensed (bool):
        version (str):
        version_url (str):
        build (Union[Unset, str]):
        build_image (Union[Unset, str]):
        build_image_url (Union[Unset, str]):
        build_url (Union[Unset, str]):
        exiftool (Union[Unset, str]):
        ffmpeg (Union[Unset, str]):
        imagemagick (Union[Unset, str]):
        libvips (Union[Unset, str]):
        nodejs (Union[Unset, str]):
        repository (Union[Unset, str]):
        repository_url (Union[Unset, str]):
        source_commit (Union[Unset, str]):
        source_ref (Union[Unset, str]):
        source_url (Union[Unset, str]):
        third_party_bug_feature_url (Union[Unset, str]):
        third_party_documentation_url (Union[Unset, str]):
        third_party_source_url (Union[Unset, str]):
        third_party_support_url (Union[Unset, str]):
    """

    licensed: bool
    version: str
    version_url: str
    build: Union[Unset, str] = UNSET
    build_image: Union[Unset, str] = UNSET
    build_image_url: Union[Unset, str] = UNSET
    build_url: Union[Unset, str] = UNSET
    exiftool: Union[Unset, str] = UNSET
    ffmpeg: Union[Unset, str] = UNSET
    imagemagick: Union[Unset, str] = UNSET
    libvips: Union[Unset, str] = UNSET
    nodejs: Union[Unset, str] = UNSET
    repository: Union[Unset, str] = UNSET
    repository_url: Union[Unset, str] = UNSET
    source_commit: Union[Unset, str] = UNSET
    source_ref: Union[Unset, str] = UNSET
    source_url: Union[Unset, str] = UNSET
    third_party_bug_feature_url: Union[Unset, str] = UNSET
    third_party_documentation_url: Union[Unset, str] = UNSET
    third_party_source_url: Union[Unset, str] = UNSET
    third_party_support_url: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        licensed = self.licensed

        version = self.version

        version_url = self.version_url

        build = self.build

        build_image = self.build_image

        build_image_url = self.build_image_url

        build_url = self.build_url

        exiftool = self.exiftool

        ffmpeg = self.ffmpeg

        imagemagick = self.imagemagick

        libvips = self.libvips

        nodejs = self.nodejs

        repository = self.repository

        repository_url = self.repository_url

        source_commit = self.source_commit

        source_ref = self.source_ref

        source_url = self.source_url

        third_party_bug_feature_url = self.third_party_bug_feature_url

        third_party_documentation_url = self.third_party_documentation_url

        third_party_source_url = self.third_party_source_url

        third_party_support_url = self.third_party_support_url

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "licensed": licensed,
                "version": version,
                "versionUrl": version_url,
            }
        )
        if build is not UNSET:
            field_dict["build"] = build
        if build_image is not UNSET:
            field_dict["buildImage"] = build_image
        if build_image_url is not UNSET:
            field_dict["buildImageUrl"] = build_image_url
        if build_url is not UNSET:
            field_dict["buildUrl"] = build_url
        if exiftool is not UNSET:
            field_dict["exiftool"] = exiftool
        if ffmpeg is not UNSET:
            field_dict["ffmpeg"] = ffmpeg
        if imagemagick is not UNSET:
            field_dict["imagemagick"] = imagemagick
        if libvips is not UNSET:
            field_dict["libvips"] = libvips
        if nodejs is not UNSET:
            field_dict["nodejs"] = nodejs
        if repository is not UNSET:
            field_dict["repository"] = repository
        if repository_url is not UNSET:
            field_dict["repositoryUrl"] = repository_url
        if source_commit is not UNSET:
            field_dict["sourceCommit"] = source_commit
        if source_ref is not UNSET:
            field_dict["sourceRef"] = source_ref
        if source_url is not UNSET:
            field_dict["sourceUrl"] = source_url
        if third_party_bug_feature_url is not UNSET:
            field_dict["thirdPartyBugFeatureUrl"] = third_party_bug_feature_url
        if third_party_documentation_url is not UNSET:
            field_dict["thirdPartyDocumentationUrl"] = third_party_documentation_url
        if third_party_source_url is not UNSET:
            field_dict["thirdPartySourceUrl"] = third_party_source_url
        if third_party_support_url is not UNSET:
            field_dict["thirdPartySupportUrl"] = third_party_support_url

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        licensed = d.pop("licensed")

        version = d.pop("version")

        version_url = d.pop("versionUrl")

        build = d.pop("build", UNSET)

        build_image = d.pop("buildImage", UNSET)

        build_image_url = d.pop("buildImageUrl", UNSET)

        build_url = d.pop("buildUrl", UNSET)

        exiftool = d.pop("exiftool", UNSET)

        ffmpeg = d.pop("ffmpeg", UNSET)

        imagemagick = d.pop("imagemagick", UNSET)

        libvips = d.pop("libvips", UNSET)

        nodejs = d.pop("nodejs", UNSET)

        repository = d.pop("repository", UNSET)

        repository_url = d.pop("repositoryUrl", UNSET)

        source_commit = d.pop("sourceCommit", UNSET)

        source_ref = d.pop("sourceRef", UNSET)

        source_url = d.pop("sourceUrl", UNSET)

        third_party_bug_feature_url = d.pop("thirdPartyBugFeatureUrl", UNSET)

        third_party_documentation_url = d.pop("thirdPartyDocumentationUrl", UNSET)

        third_party_source_url = d.pop("thirdPartySourceUrl", UNSET)

        third_party_support_url = d.pop("thirdPartySupportUrl", UNSET)

        server_about_response_dto = cls(
            licensed=licensed,
            version=version,
            version_url=version_url,
            build=build,
            build_image=build_image,
            build_image_url=build_image_url,
            build_url=build_url,
            exiftool=exiftool,
            ffmpeg=ffmpeg,
            imagemagick=imagemagick,
            libvips=libvips,
            nodejs=nodejs,
            repository=repository,
            repository_url=repository_url,
            source_commit=source_commit,
            source_ref=source_ref,
            source_url=source_url,
            third_party_bug_feature_url=third_party_bug_feature_url,
            third_party_documentation_url=third_party_documentation_url,
            third_party_source_url=third_party_source_url,
            third_party_support_url=third_party_support_url,
        )

        server_about_response_dto.additional_properties = d
        return server_about_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class UserMetadataKey(str, Enum):
    LICENSE = "license"
    ONBOARDING = "onboarding"
    PREFERENCES = "preferences"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

T = TypeVar("T", bound="UserLicense")


@_attrs_define
class UserLicense:
    """
    Attributes:
        activated_at (datetime.datetime):
        activation_key (str):
        license_key (str):
    """

    activated_at: datetime.datetime
    activation_key: str
    license_key: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        activated_at = self.activated_at.isoformat()

        activation_key = self.activation_key

        license_key = self.license_key

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "activatedAt": activated_at,
                "activationKey": activation_key,
                "licenseKey": license_key,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        activated_at = isoparse(d.pop("activatedAt"))

        activation_key = d.pop("activationKey")

        license_key = d.pop("licenseKey")

        user_license = cls(
            activated_at=activated_at,
            activation_key=activation_key,
            license_key=license_key,
        )

        user_license.additional_properties = d
        return user_license

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="SystemConfigTemplateStorageOptionDto")


@_attrs_define
class SystemConfigTemplateStorageOptionDto:
    """
    Attributes:
        day_options (list[str]):
        hour_options (list[str]):
        minute_options (list[str]):
        month_options (list[str]):
        preset_options (list[str]):
        second_options (list[str]):
        week_options (list[str]):
        year_options (list[str]):
    """

    day_options: list[str]
    hour_options: list[str]
    minute_options: list[str]
    month_options: list[str]
    preset_options: list[str]
    second_options: list[str]
    week_options: list[str]
    year_options: list[str]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        day_options = self.day_options

        hour_options = self.hour_options

        minute_options = self.minute_options

        month_options = self.month_options

        preset_options = self.preset_options

        second_options = self.second_options

        week_options = self.week_options

        year_options = self.year_options

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "dayOptions": day_options,
                "hourOptions": hour_options,
                "minuteOptions": minute_options,
                "monthOptions": month_options,
                "presetOptions": preset_options,
                "secondOptions": second_options,
                "weekOptions": week_options,
                "yearOptions": year_options,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        day_options = cast(list[str], d.pop("dayOptions"))

        hour_options = cast(list[str], d.pop("hourOptions"))

        minute_options = cast(list[str], d.pop("minuteOptions"))

        month_options = cast(list[str], d.pop("monthOptions"))

        preset_options = cast(list[str], d.pop("presetOptions"))

        second_options = cast(list[str], d.pop("secondOptions"))

        week_options = cast(list[str], d.pop("weekOptions"))

        year_options = cast(list[str], d.pop("yearOptions"))

        system_config_template_storage_option_dto = cls(
            day_options=day_options,
            hour_options=hour_options,
            minute_options=minute_options,
            month_options=month_options,
            preset_options=preset_options,
            second_options=second_options,
            week_options=week_options,
            year_options=year_options,
        )

        system_config_template_storage_option_dto.additional_properties = d
        return system_config_template_storage_option_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="PersonResponseDto")


@_attrs_define
class PersonResponseDto:
    """
    Attributes:
        birth_date (Union[None, datetime.date]):
        id (str):
        is_hidden (bool):
        name (str):
        thumbnail_path (str):
        color (Union[Unset, str]): This property was added in v1.126.0
        is_favorite (Union[Unset, bool]): This property was added in v1.126.0
        updated_at (Union[Unset, datetime.datetime]): This property was added in v1.107.0
    """

    birth_date: Union[None, datetime.date]
    id: str
    is_hidden: bool
    name: str
    thumbnail_path: str
    color: Union[Unset, str] = UNSET
    is_favorite: Union[Unset, bool] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        birth_date: Union[None, str]
        if isinstance(self.birth_date, datetime.date):
            birth_date = self.birth_date.isoformat()
        else:
            birth_date = self.birth_date

        id = self.id

        is_hidden = self.is_hidden

        name = self.name

        thumbnail_path = self.thumbnail_path

        color = self.color

        is_favorite = self.is_favorite

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "birthDate": birth_date,
                "id": id,
                "isHidden": is_hidden,
                "name": name,
                "thumbnailPath": thumbnail_path,
            }
        )
        if color is not UNSET:
            field_dict["color"] = color
        if is_favorite is not UNSET:
            field_dict["isFavorite"] = is_favorite
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_birth_date(data: object) -> Union[None, datetime.date]:
            if data is None:
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                birth_date_type_0 = isoparse(data).date()

                return birth_date_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, datetime.date], data)

        birth_date = _parse_birth_date(d.pop("birthDate"))

        id = d.pop("id")

        is_hidden = d.pop("isHidden")

        name = d.pop("name")

        thumbnail_path = d.pop("thumbnailPath")

        color = d.pop("color", UNSET)

        is_favorite = d.pop("isFavorite", UNSET)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        person_response_dto = cls(
            birth_date=birth_date,
            id=id,
            is_hidden=is_hidden,
            name=name,
            thumbnail_path=thumbnail_path,
            color=color,
            is_favorite=is_favorite,
            updated_at=updated_at,
        )

        person_response_dto.additional_properties = d
        return person_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class NotificationLevel(str, Enum):
    ERROR = "error"
    INFO = "info"
    SUCCESS = "success"
    WARNING = "warning"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class TranscodePolicy(str, Enum):
    ALL = "all"
    BITRATE = "bitrate"
    DISABLED = "disabled"
    OPTIMAL = "optimal"
    REQUIRED = "required"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
    cast,
)
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.asset_visibility import AssetVisibility
from ..types import UNSET, Unset

T = TypeVar("T", bound="UpdateAssetDto")


@_attrs_define
class UpdateAssetDto:
    """
    Attributes:
        date_time_original (Union[Unset, str]):
        description (Union[Unset, str]):
        is_favorite (Union[Unset, bool]):
        latitude (Union[Unset, float]):
        live_photo_video_id (Union[None, UUID, Unset]):
        longitude (Union[Unset, float]):
        rating (Union[Unset, float]):
        visibility (Union[Unset, AssetVisibility]):
    """

    date_time_original: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    is_favorite: Union[Unset, bool] = UNSET
    latitude: Union[Unset, float] = UNSET
    live_photo_video_id: Union[None, UUID, Unset] = UNSET
    longitude: Union[Unset, float] = UNSET
    rating: Union[Unset, float] = UNSET
    visibility: Union[Unset, AssetVisibility] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        date_time_original = self.date_time_original

        description = self.description

        is_favorite = self.is_favorite

        latitude = self.latitude

        live_photo_video_id: Union[None, Unset, str]
        if isinstance(self.live_photo_video_id, Unset):
            live_photo_video_id = UNSET
        elif isinstance(self.live_photo_video_id, UUID):
            live_photo_video_id = str(self.live_photo_video_id)
        else:
            live_photo_video_id = self.live_photo_video_id

        longitude = self.longitude

        rating = self.rating

        visibility: Union[Unset, str] = UNSET
        if not isinstance(self.visibility, Unset):
            visibility = self.visibility.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if date_time_original is not UNSET:
            field_dict["dateTimeOriginal"] = date_time_original
        if description is not UNSET:
            field_dict["description"] = description
        if is_favorite is not UNSET:
            field_dict["isFavorite"] = is_favorite
        if latitude is not UNSET:
            field_dict["latitude"] = latitude
        if live_photo_video_id is not UNSET:
            field_dict["livePhotoVideoId"] = live_photo_video_id
        if longitude is not UNSET:
            field_dict["longitude"] = longitude
        if rating is not UNSET:
            field_dict["rating"] = rating
        if visibility is not UNSET:
            field_dict["visibility"] = visibility

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        date_time_original = d.pop("dateTimeOriginal", UNSET)

        description = d.pop("description", UNSET)

        is_favorite = d.pop("isFavorite", UNSET)

        latitude = d.pop("latitude", UNSET)

        def _parse_live_photo_video_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                live_photo_video_id_type_0 = UUID(data)

                return live_photo_video_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        live_photo_video_id = _parse_live_photo_video_id(
            d.pop("livePhotoVideoId", UNSET)
        )

        longitude = d.pop("longitude", UNSET)

        rating = d.pop("rating", UNSET)

        _visibility = d.pop("visibility", UNSET)
        visibility: Union[Unset, AssetVisibility]
        if isinstance(_visibility, Unset):
            visibility = UNSET
        else:
            visibility = AssetVisibility(_visibility)

        update_asset_dto = cls(
            date_time_original=date_time_original,
            description=description,
            is_favorite=is_favorite,
            latitude=latitude,
            live_photo_video_id=live_photo_video_id,
            longitude=longitude,
            rating=rating,
            visibility=visibility,
        )

        update_asset_dto.additional_properties = d
        return update_asset_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="ServerMediaTypesResponseDto")


@_attrs_define
class ServerMediaTypesResponseDto:
    """
    Attributes:
        image (list[str]):
        sidecar (list[str]):
        video (list[str]):
    """

    image: list[str]
    sidecar: list[str]
    video: list[str]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        image = self.image

        sidecar = self.sidecar

        video = self.video

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "image": image,
                "sidecar": sidecar,
                "video": video,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        image = cast(list[str], d.pop("image"))

        sidecar = cast(list[str], d.pop("sidecar"))

        video = cast(list[str], d.pop("video"))

        server_media_types_response_dto = cls(
            image=image,
            sidecar=sidecar,
            video=video,
        )

        server_media_types_response_dto.additional_properties = d
        return server_media_types_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.api_key_response_dto import APIKeyResponseDto


T = TypeVar("T", bound="APIKeyCreateResponseDto")


@_attrs_define
class APIKeyCreateResponseDto:
    """
    Attributes:
        api_key (APIKeyResponseDto):
        secret (str):
    """

    api_key: "APIKeyResponseDto"
    secret: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        api_key = self.api_key.to_dict()

        secret = self.secret

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "apiKey": api_key,
                "secret": secret,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.api_key_response_dto import APIKeyResponseDto

        d = dict(src_dict)
        api_key = APIKeyResponseDto.from_dict(d.pop("apiKey"))

        secret = d.pop("secret")

        api_key_create_response_dto = cls(
            api_key=api_key,
            secret=secret,
        )

        api_key_create_response_dto.additional_properties = d
        return api_key_create_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
)
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="StackUpdateDto")


@_attrs_define
class StackUpdateDto:
    """
    Attributes:
        primary_asset_id (Union[Unset, UUID]):
    """

    primary_asset_id: Union[Unset, UUID] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        primary_asset_id: Union[Unset, str] = UNSET
        if not isinstance(self.primary_asset_id, Unset):
            primary_asset_id = str(self.primary_asset_id)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if primary_asset_id is not UNSET:
            field_dict["primaryAssetId"] = primary_asset_id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _primary_asset_id = d.pop("primaryAssetId", UNSET)
        primary_asset_id: Union[Unset, UUID]
        if isinstance(_primary_asset_id, Unset):
            primary_asset_id = UNSET
        else:
            primary_asset_id = UUID(_primary_asset_id)

        stack_update_dto = cls(
            primary_asset_id=primary_asset_id,
        )

        stack_update_dto.additional_properties = d
        return stack_update_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="SystemConfigTemplateEmailsDto")


@_attrs_define
class SystemConfigTemplateEmailsDto:
    """
    Attributes:
        album_invite_template (str):
        album_update_template (str):
        welcome_template (str):
    """

    album_invite_template: str
    album_update_template: str
    welcome_template: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        album_invite_template = self.album_invite_template

        album_update_template = self.album_update_template

        welcome_template = self.welcome_template

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "albumInviteTemplate": album_invite_template,
                "albumUpdateTemplate": album_update_template,
                "welcomeTemplate": welcome_template,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        album_invite_template = d.pop("albumInviteTemplate")

        album_update_template = d.pop("albumUpdateTemplate")

        welcome_template = d.pop("welcomeTemplate")

        system_config_template_emails_dto = cls(
            album_invite_template=album_invite_template,
            album_update_template=album_update_template,
            welcome_template=welcome_template,
        )

        system_config_template_emails_dto.additional_properties = d
        return system_config_template_emails_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.asset_order import AssetOrder
from ...models.asset_visibility import AssetVisibility
from ...models.time_bucket_asset_response_dto import TimeBucketAssetResponseDto
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    album_id: Union[Unset, UUID] = UNSET,
    is_favorite: Union[Unset, bool] = UNSET,
    is_trashed: Union[Unset, bool] = UNSET,
    key: Union[Unset, str] = UNSET,
    order: Union[Unset, AssetOrder] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    slug: Union[Unset, str] = UNSET,
    tag_id: Union[Unset, UUID] = UNSET,
    time_bucket: str,
    user_id: Union[Unset, UUID] = UNSET,
    visibility: Union[Unset, AssetVisibility] = UNSET,
    with_coordinates: Union[Unset, bool] = UNSET,
    with_partners: Union[Unset, bool] = UNSET,
    with_stacked: Union[Unset, bool] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_album_id: Union[Unset, str] = UNSET
    if not isinstance(album_id, Unset):
        json_album_id = str(album_id)
    params["albumId"] = json_album_id

    params["isFavorite"] = is_favorite

    params["isTrashed"] = is_trashed

    params["key"] = key

    json_order: Union[Unset, str] = UNSET
    if not isinstance(order, Unset):
        json_order = order.value

    params["order"] = json_order

    json_person_id: Union[Unset, str] = UNSET
    if not isinstance(person_id, Unset):
        json_person_id = str(person_id)
    params["personId"] = json_person_id

    params["slug"] = slug

    json_tag_id: Union[Unset, str] = UNSET
    if not isinstance(tag_id, Unset):
        json_tag_id = str(tag_id)
    params["tagId"] = json_tag_id

    params["timeBucket"] = time_bucket

    json_user_id: Union[Unset, str] = UNSET
    if not isinstance(user_id, Unset):
        json_user_id = str(user_id)
    params["userId"] = json_user_id

    json_visibility: Union[Unset, str] = UNSET
    if not isinstance(visibility, Unset):
        json_visibility = visibility.value

    params["visibility"] = json_visibility

    params["withCoordinates"] = with_coordinates

    params["withPartners"] = with_partners

    params["withStacked"] = with_stacked

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/timeline/bucket",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[TimeBucketAssetResponseDto]:
    if response.status_code == 200:
        response_200 = TimeBucketAssetResponseDto.from_dict(response.json())

        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[TimeBucketAssetResponseDto]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    album_id: Union[Unset, UUID] = UNSET,
    is_favorite: Union[Unset, bool] = UNSET,
    is_trashed: Union[Unset, bool] = UNSET,
    key: Union[Unset, str] = UNSET,
    order: Union[Unset, AssetOrder] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    slug: Union[Unset, str] = UNSET,
    tag_id: Union[Unset, UUID] = UNSET,
    time_bucket: str,
    user_id: Union[Unset, UUID] = UNSET,
    visibility: Union[Unset, AssetVisibility] = UNSET,
    with_coordinates: Union[Unset, bool] = UNSET,
    with_partners: Union[Unset, bool] = UNSET,
    with_stacked: Union[Unset, bool] = UNSET,
) -> Response[TimeBucketAssetResponseDto]:
    """This endpoint requires the `asset.read` permission.

    Args:
        album_id (Union[Unset, UUID]):
        is_favorite (Union[Unset, bool]):
        is_trashed (Union[Unset, bool]):
        key (Union[Unset, str]):
        order (Union[Unset, AssetOrder]):
        person_id (Union[Unset, UUID]):
        slug (Union[Unset, str]):
        tag_id (Union[Unset, UUID]):
        time_bucket (str):  Example: 2024-01-01.
        user_id (Union[Unset, UUID]):
        visibility (Union[Unset, AssetVisibility]):
        with_coordinates (Union[Unset, bool]):
        with_partners (Union[Unset, bool]):
        with_stacked (Union[Unset, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[TimeBucketAssetResponseDto]
    """

    kwargs = _get_kwargs(
        album_id=album_id,
        is_favorite=is_favorite,
        is_trashed=is_trashed,
        key=key,
        order=order,
        person_id=person_id,
        slug=slug,
        tag_id=tag_id,
        time_bucket=time_bucket,
        user_id=user_id,
        visibility=visibility,
        with_coordinates=with_coordinates,
        with_partners=with_partners,
        with_stacked=with_stacked,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    album_id: Union[Unset, UUID] = UNSET,
    is_favorite: Union[Unset, bool] = UNSET,
    is_trashed: Union[Unset, bool] = UNSET,
    key: Union[Unset, str] = UNSET,
    order: Union[Unset, AssetOrder] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    slug: Union[Unset, str] = UNSET,
    tag_id: Union[Unset, UUID] = UNSET,
    time_bucket: str,
    user_id: Union[Unset, UUID] = UNSET,
    visibility: Union[Unset, AssetVisibility] = UNSET,
    with_coordinates: Union[Unset, bool] = UNSET,
    with_partners: Union[Unset, bool] = UNSET,
    with_stacked: Union[Unset, bool] = UNSET,
) -> Optional[TimeBucketAssetResponseDto]:
    """This endpoint requires the `asset.read` permission.

    Args:
        album_id (Union[Unset, UUID]):
        is_favorite (Union[Unset, bool]):
        is_trashed (Union[Unset, bool]):
        key (Union[Unset, str]):
        order (Union[Unset, AssetOrder]):
        person_id (Union[Unset, UUID]):
        slug (Union[Unset, str]):
        tag_id (Union[Unset, UUID]):
        time_bucket (str):  Example: 2024-01-01.
        user_id (Union[Unset, UUID]):
        visibility (Union[Unset, AssetVisibility]):
        with_coordinates (Union[Unset, bool]):
        with_partners (Union[Unset, bool]):
        with_stacked (Union[Unset, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        TimeBucketAssetResponseDto
    """

    return sync_detailed(
        client=client,
        album_id=album_id,
        is_favorite=is_favorite,
        is_trashed=is_trashed,
        key=key,
        order=order,
        person_id=person_id,
        slug=slug,
        tag_id=tag_id,
        time_bucket=time_bucket,
        user_id=user_id,
        visibility=visibility,
        with_coordinates=with_coordinates,
        with_partners=with_partners,
        with_stacked=with_stacked,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    album_id: Union[Unset, UUID] = UNSET,
    is_favorite: Union[Unset, bool] = UNSET,
    is_trashed: Union[Unset, bool] = UNSET,
    key: Union[Unset, str] = UNSET,
    order: Union[Unset, AssetOrder] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    slug: Union[Unset, str] = UNSET,
    tag_id: Union[Unset, UUID] = UNSET,
    time_bucket: str,
    user_id: Union[Unset, UUID] = UNSET,
    visibility: Union[Unset, AssetVisibility] = UNSET,
    with_coordinates: Union[Unset, bool] = UNSET,
    with_partners: Union[Unset, bool] = UNSET,
    with_stacked: Union[Unset, bool] = UNSET,
) -> Response[TimeBucketAssetResponseDto]:
    """This endpoint requires the `asset.read` permission.

    Args:
        album_id (Union[Unset, UUID]):
        is_favorite (Union[Unset, bool]):
        is_trashed (Union[Unset, bool]):
        key (Union[Unset, str]):
        order (Union[Unset, AssetOrder]):
        person_id (Union[Unset, UUID]):
        slug (Union[Unset, str]):
        tag_id (Union[Unset, UUID]):
        time_bucket (str):  Example: 2024-01-01.
        user_id (Union[Unset, UUID]):
        visibility (Union[Unset, AssetVisibility]):
        with_coordinates (Union[Unset, bool]):
        with_partners (Union[Unset, bool]):
        with_stacked (Union[Unset, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[TimeBucketAssetResponseDto]
    """

    kwargs = _get_kwargs(
        album_id=album_id,
        is_favorite=is_favorite,
        is_trashed=is_trashed,
        key=key,
        order=order,
        person_id=person_id,
        slug=slug,
        tag_id=tag_id,
        time_bucket=time_bucket,
        user_id=user_id,
        visibility=visibility,
        with_coordinates=with_coordinates,
        with_partners=with_partners,
        with_stacked=with_stacked,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    album_id: Union[Unset, UUID] = UNSET,
    is_favorite: Union[Unset, bool] = UNSET,
    is_trashed: Union[Unset, bool] = UNSET,
    key: Union[Unset, str] = UNSET,
    order: Union[Unset, AssetOrder] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    slug: Union[Unset, str] = UNSET,
    tag_id: Union[Unset, UUID] = UNSET,
    time_bucket: str,
    user_id: Union[Unset, UUID] = UNSET,
    visibility: Union[Unset, AssetVisibility] = UNSET,
    with_coordinates: Union[Unset, bool] = UNSET,
    with_partners: Union[Unset, bool] = UNSET,
    with_stacked: Union[Unset, bool] = UNSET,
) -> Optional[TimeBucketAssetResponseDto]:
    """This endpoint requires the `asset.read` permission.

    Args:
        album_id (Union[Unset, UUID]):
        is_favorite (Union[Unset, bool]):
        is_trashed (Union[Unset, bool]):
        key (Union[Unset, str]):
        order (Union[Unset, AssetOrder]):
        person_id (Union[Unset, UUID]):
        slug (Union[Unset, str]):
        tag_id (Union[Unset, UUID]):
        time_bucket (str):  Example: 2024-01-01.
        user_id (Union[Unset, UUID]):
        visibility (Union[Unset, AssetVisibility]):
        with_coordinates (Union[Unset, bool]):
        with_partners (Union[Unset, bool]):
        with_stacked (Union[Unset, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        TimeBucketAssetResponseDto
    """

    return (
        await asyncio_detailed(
            client=client,
            album_id=album_id,
            is_favorite=is_favorite,
            is_trashed=is_trashed,
            key=key,
            order=order,
            person_id=person_id,
            slug=slug,
            tag_id=tag_id,
            time_bucket=time_bucket,
            user_id=user_id,
            visibility=visibility,
            with_coordinates=with_coordinates,
            with_partners=with_partners,
            with_stacked=with_stacked,
        )
    ).parsed



from enum import Enum


class JobCommand(str, Enum):
    CLEAR_FAILED = "clear-failed"
    EMPTY = "empty"
    PAUSE = "pause"
    RESUME = "resume"
    START = "start"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.search_facet_count_response_dto import SearchFacetCountResponseDto


T = TypeVar("T", bound="SearchFacetResponseDto")


@_attrs_define
class SearchFacetResponseDto:
    """
    Attributes:
        counts (list['SearchFacetCountResponseDto']):
        field_name (str):
    """

    counts: list["SearchFacetCountResponseDto"]
    field_name: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        counts = []
        for counts_item_data in self.counts:
            counts_item = counts_item_data.to_dict()
            counts.append(counts_item)

        field_name = self.field_name

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "counts": counts,
                "fieldName": field_name,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.search_facet_count_response_dto import SearchFacetCountResponseDto

        d = dict(src_dict)
        counts = []
        _counts = d.pop("counts")
        for counts_item_data in _counts:
            counts_item = SearchFacetCountResponseDto.from_dict(counts_item_data)

            counts.append(counts_item)

        field_name = d.pop("fieldName")

        search_facet_response_dto = cls(
            counts=counts,
            field_name=field_name,
        )

        search_facet_response_dto.additional_properties = d
        return search_facet_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.o_auth_token_endpoint_auth_method import OAuthTokenEndpointAuthMethod

T = TypeVar("T", bound="SystemConfigOAuthDto")


@_attrs_define
class SystemConfigOAuthDto:
    """
    Attributes:
        auto_launch (bool):
        auto_register (bool):
        button_text (str):
        client_id (str):
        client_secret (str):
        default_storage_quota (Union[None, int]):
        enabled (bool):
        issuer_url (str):
        mobile_override_enabled (bool):
        mobile_redirect_uri (str):
        profile_signing_algorithm (str):
        role_claim (str):
        scope (str):
        signing_algorithm (str):
        storage_label_claim (str):
        storage_quota_claim (str):
        timeout (int):
        token_endpoint_auth_method (OAuthTokenEndpointAuthMethod):
    """

    auto_launch: bool
    auto_register: bool
    button_text: str
    client_id: str
    client_secret: str
    default_storage_quota: Union[None, int]
    enabled: bool
    issuer_url: str
    mobile_override_enabled: bool
    mobile_redirect_uri: str
    profile_signing_algorithm: str
    role_claim: str
    scope: str
    signing_algorithm: str
    storage_label_claim: str
    storage_quota_claim: str
    timeout: int
    token_endpoint_auth_method: OAuthTokenEndpointAuthMethod
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        auto_launch = self.auto_launch

        auto_register = self.auto_register

        button_text = self.button_text

        client_id = self.client_id

        client_secret = self.client_secret

        default_storage_quota: Union[None, int]
        default_storage_quota = self.default_storage_quota

        enabled = self.enabled

        issuer_url = self.issuer_url

        mobile_override_enabled = self.mobile_override_enabled

        mobile_redirect_uri = self.mobile_redirect_uri

        profile_signing_algorithm = self.profile_signing_algorithm

        role_claim = self.role_claim

        scope = self.scope

        signing_algorithm = self.signing_algorithm

        storage_label_claim = self.storage_label_claim

        storage_quota_claim = self.storage_quota_claim

        timeout = self.timeout

        token_endpoint_auth_method = self.token_endpoint_auth_method.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "autoLaunch": auto_launch,
                "autoRegister": auto_register,
                "buttonText": button_text,
                "clientId": client_id,
                "clientSecret": client_secret,
                "defaultStorageQuota": default_storage_quota,
                "enabled": enabled,
                "issuerUrl": issuer_url,
                "mobileOverrideEnabled": mobile_override_enabled,
                "mobileRedirectUri": mobile_redirect_uri,
                "profileSigningAlgorithm": profile_signing_algorithm,
                "roleClaim": role_claim,
                "scope": scope,
                "signingAlgorithm": signing_algorithm,
                "storageLabelClaim": storage_label_claim,
                "storageQuotaClaim": storage_quota_claim,
                "timeout": timeout,
                "tokenEndpointAuthMethod": token_endpoint_auth_method,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        auto_launch = d.pop("autoLaunch")

        auto_register = d.pop("autoRegister")

        button_text = d.pop("buttonText")

        client_id = d.pop("clientId")

        client_secret = d.pop("clientSecret")

        def _parse_default_storage_quota(data: object) -> Union[None, int]:
            if data is None:
                return data
            return cast(Union[None, int], data)

        default_storage_quota = _parse_default_storage_quota(
            d.pop("defaultStorageQuota")
        )

        enabled = d.pop("enabled")

        issuer_url = d.pop("issuerUrl")

        mobile_override_enabled = d.pop("mobileOverrideEnabled")

        mobile_redirect_uri = d.pop("mobileRedirectUri")

        profile_signing_algorithm = d.pop("profileSigningAlgorithm")

        role_claim = d.pop("roleClaim")

        scope = d.pop("scope")

        signing_algorithm = d.pop("signingAlgorithm")

        storage_label_claim = d.pop("storageLabelClaim")

        storage_quota_claim = d.pop("storageQuotaClaim")

        timeout = d.pop("timeout")

        token_endpoint_auth_method = OAuthTokenEndpointAuthMethod(
            d.pop("tokenEndpointAuthMethod")
        )

        system_config_o_auth_dto = cls(
            auto_launch=auto_launch,
            auto_register=auto_register,
            button_text=button_text,
            client_id=client_id,
            client_secret=client_secret,
            default_storage_quota=default_storage_quota,
            enabled=enabled,
            issuer_url=issuer_url,
            mobile_override_enabled=mobile_override_enabled,
            mobile_redirect_uri=mobile_redirect_uri,
            profile_signing_algorithm=profile_signing_algorithm,
            role_claim=role_claim,
            scope=scope,
            signing_algorithm=signing_algorithm,
            storage_label_claim=storage_label_claim,
            storage_quota_claim=storage_quota_claim,
            timeout=timeout,
            token_endpoint_auth_method=token_endpoint_auth_method,
        )

        system_config_o_auth_dto.additional_properties = d
        return system_config_o_auth_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class SyncRequestType(str, Enum):
    ALBUMASSETEXIFSV1 = "AlbumAssetExifsV1"
    ALBUMASSETSV1 = "AlbumAssetsV1"
    ALBUMSV1 = "AlbumsV1"
    ALBUMTOASSETSV1 = "AlbumToAssetsV1"
    ALBUMUSERSV1 = "AlbumUsersV1"
    ASSETEXIFSV1 = "AssetExifsV1"
    ASSETFACESV1 = "AssetFacesV1"
    ASSETMETADATAV1 = "AssetMetadataV1"
    ASSETSV1 = "AssetsV1"
    AUTHUSERSV1 = "AuthUsersV1"
    MEMORIESV1 = "MemoriesV1"
    MEMORYTOASSETSV1 = "MemoryToAssetsV1"
    PARTNERASSETEXIFSV1 = "PartnerAssetExifsV1"
    PARTNERASSETSV1 = "PartnerAssetsV1"
    PARTNERSTACKSV1 = "PartnerStacksV1"
    PARTNERSV1 = "PartnersV1"
    PEOPLEV1 = "PeopleV1"
    STACKSV1 = "StacksV1"
    USERMETADATAV1 = "UserMetadataV1"
    USERSV1 = "UsersV1"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.asset_bulk_upload_check_result_action import (
    AssetBulkUploadCheckResultAction,
)
from ..models.asset_bulk_upload_check_result_reason import (
    AssetBulkUploadCheckResultReason,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="AssetBulkUploadCheckResult")


@_attrs_define
class AssetBulkUploadCheckResult:
    """
    Attributes:
        action (AssetBulkUploadCheckResultAction):
        id (str):
        asset_id (Union[Unset, str]):
        is_trashed (Union[Unset, bool]):
        reason (Union[Unset, AssetBulkUploadCheckResultReason]):
    """

    action: AssetBulkUploadCheckResultAction
    id: str
    asset_id: Union[Unset, str] = UNSET
    is_trashed: Union[Unset, bool] = UNSET
    reason: Union[Unset, AssetBulkUploadCheckResultReason] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        action = self.action.value

        id = self.id

        asset_id = self.asset_id

        is_trashed = self.is_trashed

        reason: Union[Unset, str] = UNSET
        if not isinstance(self.reason, Unset):
            reason = self.reason.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "action": action,
                "id": id,
            }
        )
        if asset_id is not UNSET:
            field_dict["assetId"] = asset_id
        if is_trashed is not UNSET:
            field_dict["isTrashed"] = is_trashed
        if reason is not UNSET:
            field_dict["reason"] = reason

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        action = AssetBulkUploadCheckResultAction(d.pop("action"))

        id = d.pop("id")

        asset_id = d.pop("assetId", UNSET)

        is_trashed = d.pop("isTrashed", UNSET)

        _reason = d.pop("reason", UNSET)
        reason: Union[Unset, AssetBulkUploadCheckResultReason]
        if isinstance(_reason, Unset):
            reason = UNSET
        else:
            reason = AssetBulkUploadCheckResultReason(_reason)

        asset_bulk_upload_check_result = cls(
            action=action,
            id=id,
            asset_id=asset_id,
            is_trashed=is_trashed,
            reason=reason,
        )

        asset_bulk_upload_check_result.additional_properties = d
        return asset_bulk_upload_check_result

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from io import BytesIO
from typing import (
    Any,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from .. import types
from ..types import UNSET, File, Unset

T = TypeVar("T", bound="AssetMediaReplaceDto")


@_attrs_define
class AssetMediaReplaceDto:
    """
    Attributes:
        asset_data (File):
        device_asset_id (str):
        device_id (str):
        file_created_at (datetime.datetime):
        file_modified_at (datetime.datetime):
        duration (Union[Unset, str]):
        filename (Union[Unset, str]):
    """

    asset_data: File
    device_asset_id: str
    device_id: str
    file_created_at: datetime.datetime
    file_modified_at: datetime.datetime
    duration: Union[Unset, str] = UNSET
    filename: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        asset_data = self.asset_data.to_tuple()

        device_asset_id = self.device_asset_id

        device_id = self.device_id

        file_created_at = self.file_created_at.isoformat()

        file_modified_at = self.file_modified_at.isoformat()

        duration = self.duration

        filename = self.filename

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "assetData": asset_data,
                "deviceAssetId": device_asset_id,
                "deviceId": device_id,
                "fileCreatedAt": file_created_at,
                "fileModifiedAt": file_modified_at,
            }
        )
        if duration is not UNSET:
            field_dict["duration"] = duration
        if filename is not UNSET:
            field_dict["filename"] = filename

        return field_dict

    def to_multipart(self) -> types.RequestFiles:
        files: types.RequestFiles = []

        files.append(("assetData", self.asset_data.to_tuple()))

        files.append(
            ("deviceAssetId", (None, str(self.device_asset_id).encode(), "text/plain"))
        )

        files.append(("deviceId", (None, str(self.device_id).encode(), "text/plain")))

        files.append(
            (
                "fileCreatedAt",
                (None, self.file_created_at.isoformat().encode(), "text/plain"),
            )
        )

        files.append(
            (
                "fileModifiedAt",
                (None, self.file_modified_at.isoformat().encode(), "text/plain"),
            )
        )

        if not isinstance(self.duration, Unset):
            files.append(
                ("duration", (None, str(self.duration).encode(), "text/plain"))
            )

        if not isinstance(self.filename, Unset):
            files.append(
                ("filename", (None, str(self.filename).encode(), "text/plain"))
            )

        for prop_name, prop in self.additional_properties.items():
            files.append((prop_name, (None, str(prop).encode(), "text/plain")))

        return files

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        asset_data = File(payload=BytesIO(d.pop("assetData")))

        device_asset_id = d.pop("deviceAssetId")

        device_id = d.pop("deviceId")

        file_created_at = isoparse(d.pop("fileCreatedAt"))

        file_modified_at = isoparse(d.pop("fileModifiedAt"))

        duration = d.pop("duration", UNSET)

        filename = d.pop("filename", UNSET)

        asset_media_replace_dto = cls(
            asset_data=asset_data,
            device_asset_id=device_asset_id,
            device_id=device_id,
            file_created_at=file_created_at,
            file_modified_at=file_modified_at,
            duration=duration,
            filename=filename,
        )

        asset_media_replace_dto.additional_properties = d
        return asset_media_replace_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class LogLevel(str, Enum):
    DEBUG = "debug"
    ERROR = "error"
    FATAL = "fatal"
    LOG = "log"
    VERBOSE = "verbose"
    WARN = "warn"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class AssetJobName(str, Enum):
    REFRESH_FACES = "refresh-faces"
    REFRESH_METADATA = "refresh-metadata"
    REGENERATE_THUMBNAIL = "regenerate-thumbnail"
    TRANSCODE_VIDEO = "transcode-video"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.job_status_dto import JobStatusDto


T = TypeVar("T", bound="AllJobStatusResponseDto")


@_attrs_define
class AllJobStatusResponseDto:
    """
    Attributes:
        background_task (JobStatusDto):
        backup_database (JobStatusDto):
        duplicate_detection (JobStatusDto):
        face_detection (JobStatusDto):
        facial_recognition (JobStatusDto):
        library (JobStatusDto):
        metadata_extraction (JobStatusDto):
        migration (JobStatusDto):
        notifications (JobStatusDto):
        search (JobStatusDto):
        sidecar (JobStatusDto):
        smart_search (JobStatusDto):
        storage_template_migration (JobStatusDto):
        thumbnail_generation (JobStatusDto):
        video_conversion (JobStatusDto):
    """

    background_task: "JobStatusDto"
    backup_database: "JobStatusDto"
    duplicate_detection: "JobStatusDto"
    face_detection: "JobStatusDto"
    facial_recognition: "JobStatusDto"
    library: "JobStatusDto"
    metadata_extraction: "JobStatusDto"
    migration: "JobStatusDto"
    notifications: "JobStatusDto"
    search: "JobStatusDto"
    sidecar: "JobStatusDto"
    smart_search: "JobStatusDto"
    storage_template_migration: "JobStatusDto"
    thumbnail_generation: "JobStatusDto"
    video_conversion: "JobStatusDto"
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        background_task = self.background_task.to_dict()

        backup_database = self.backup_database.to_dict()

        duplicate_detection = self.duplicate_detection.to_dict()

        face_detection = self.face_detection.to_dict()

        facial_recognition = self.facial_recognition.to_dict()

        library = self.library.to_dict()

        metadata_extraction = self.metadata_extraction.to_dict()

        migration = self.migration.to_dict()

        notifications = self.notifications.to_dict()

        search = self.search.to_dict()

        sidecar = self.sidecar.to_dict()

        smart_search = self.smart_search.to_dict()

        storage_template_migration = self.storage_template_migration.to_dict()

        thumbnail_generation = self.thumbnail_generation.to_dict()

        video_conversion = self.video_conversion.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "backgroundTask": background_task,
                "backupDatabase": backup_database,
                "duplicateDetection": duplicate_detection,
                "faceDetection": face_detection,
                "facialRecognition": facial_recognition,
                "library": library,
                "metadataExtraction": metadata_extraction,
                "migration": migration,
                "notifications": notifications,
                "search": search,
                "sidecar": sidecar,
                "smartSearch": smart_search,
                "storageTemplateMigration": storage_template_migration,
                "thumbnailGeneration": thumbnail_generation,
                "videoConversion": video_conversion,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.job_status_dto import JobStatusDto

        d = dict(src_dict)
        background_task = JobStatusDto.from_dict(d.pop("backgroundTask"))

        backup_database = JobStatusDto.from_dict(d.pop("backupDatabase"))

        duplicate_detection = JobStatusDto.from_dict(d.pop("duplicateDetection"))

        face_detection = JobStatusDto.from_dict(d.pop("faceDetection"))

        facial_recognition = JobStatusDto.from_dict(d.pop("facialRecognition"))

        library = JobStatusDto.from_dict(d.pop("library"))

        metadata_extraction = JobStatusDto.from_dict(d.pop("metadataExtraction"))

        migration = JobStatusDto.from_dict(d.pop("migration"))

        notifications = JobStatusDto.from_dict(d.pop("notifications"))

        search = JobStatusDto.from_dict(d.pop("search"))

        sidecar = JobStatusDto.from_dict(d.pop("sidecar"))

        smart_search = JobStatusDto.from_dict(d.pop("smartSearch"))

        storage_template_migration = JobStatusDto.from_dict(
            d.pop("storageTemplateMigration")
        )

        thumbnail_generation = JobStatusDto.from_dict(d.pop("thumbnailGeneration"))

        video_conversion = JobStatusDto.from_dict(d.pop("videoConversion"))

        all_job_status_response_dto = cls(
            background_task=background_task,
            backup_database=backup_database,
            duplicate_detection=duplicate_detection,
            face_detection=face_detection,
            facial_recognition=facial_recognition,
            library=library,
            metadata_extraction=metadata_extraction,
            migration=migration,
            notifications=notifications,
            search=search,
            sidecar=sidecar,
            smart_search=smart_search,
            storage_template_migration=storage_template_migration,
            thumbnail_generation=thumbnail_generation,
            video_conversion=video_conversion,
        )

        all_job_status_response_dto.additional_properties = d
        return all_job_status_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

T = TypeVar("T", bound="LibraryResponseDto")


@_attrs_define
class LibraryResponseDto:
    """
    Attributes:
        asset_count (int):
        created_at (datetime.datetime):
        exclusion_patterns (list[str]):
        id (str):
        import_paths (list[str]):
        name (str):
        owner_id (str):
        refreshed_at (Union[None, datetime.datetime]):
        updated_at (datetime.datetime):
    """

    asset_count: int
    created_at: datetime.datetime
    exclusion_patterns: list[str]
    id: str
    import_paths: list[str]
    name: str
    owner_id: str
    refreshed_at: Union[None, datetime.datetime]
    updated_at: datetime.datetime
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        asset_count = self.asset_count

        created_at = self.created_at.isoformat()

        exclusion_patterns = self.exclusion_patterns

        id = self.id

        import_paths = self.import_paths

        name = self.name

        owner_id = self.owner_id

        refreshed_at: Union[None, str]
        if isinstance(self.refreshed_at, datetime.datetime):
            refreshed_at = self.refreshed_at.isoformat()
        else:
            refreshed_at = self.refreshed_at

        updated_at = self.updated_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "assetCount": asset_count,
                "createdAt": created_at,
                "exclusionPatterns": exclusion_patterns,
                "id": id,
                "importPaths": import_paths,
                "name": name,
                "ownerId": owner_id,
                "refreshedAt": refreshed_at,
                "updatedAt": updated_at,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        asset_count = d.pop("assetCount")

        created_at = isoparse(d.pop("createdAt"))

        exclusion_patterns = cast(list[str], d.pop("exclusionPatterns"))

        id = d.pop("id")

        import_paths = cast(list[str], d.pop("importPaths"))

        name = d.pop("name")

        owner_id = d.pop("ownerId")

        def _parse_refreshed_at(data: object) -> Union[None, datetime.datetime]:
            if data is None:
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                refreshed_at_type_0 = isoparse(data)

                return refreshed_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, datetime.datetime], data)

        refreshed_at = _parse_refreshed_at(d.pop("refreshedAt"))

        updated_at = isoparse(d.pop("updatedAt"))

        library_response_dto = cls(
            asset_count=asset_count,
            created_at=created_at,
            exclusion_patterns=exclusion_patterns,
            id=id,
            import_paths=import_paths,
            name=name,
            owner_id=owner_id,
            refreshed_at=refreshed_at,
            updated_at=updated_at,
        )

        library_response_dto.additional_properties = d
        return library_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="SystemConfigServerDto")


@_attrs_define
class SystemConfigServerDto:
    """
    Attributes:
        external_domain (str):
        login_page_message (str):
        public_users (bool):
    """

    external_domain: str
    login_page_message: str
    public_users: bool
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        external_domain = self.external_domain

        login_page_message = self.login_page_message

        public_users = self.public_users

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "externalDomain": external_domain,
                "loginPageMessage": login_page_message,
                "publicUsers": public_users,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        external_domain = d.pop("externalDomain")

        login_page_message = d.pop("loginPageMessage")

        public_users = d.pop("publicUsers")

        system_config_server_dto = cls(
            external_domain=external_domain,
            login_page_message=login_page_message,
            public_users=public_users,
        )

        system_config_server_dto.additional_properties = d
        return system_config_server_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class JobName(str, Enum):
    BACKGROUNDTASK = "backgroundTask"
    BACKUPDATABASE = "backupDatabase"
    DUPLICATEDETECTION = "duplicateDetection"
    FACEDETECTION = "faceDetection"
    FACIALRECOGNITION = "facialRecognition"
    LIBRARY = "library"
    METADATAEXTRACTION = "metadataExtraction"
    MIGRATION = "migration"
    NOTIFICATIONS = "notifications"
    SEARCH = "search"
    SIDECAR = "sidecar"
    SMARTSEARCH = "smartSearch"
    STORAGETEMPLATEMIGRATION = "storageTemplateMigration"
    THUMBNAILGENERATION = "thumbnailGeneration"
    VIDEOCONVERSION = "videoConversion"

    def __str__(self) -> str:
        return str(self.value)
